summaryrefslogtreecommitdiffstats
path: root/msg.py
diff options
context:
space:
mode:
Diffstat (limited to 'msg.py')
-rw-r--r--msg.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/msg.py b/msg.py
index b20dea4..1a27886 100644
--- a/msg.py
+++ b/msg.py
@@ -1,4 +1,4 @@
# Messages used by bootconf.
# Michael DeHaan <mdehaan@redhat.com>
"""
@@ -7,19 +7,19 @@ be reused and potentially translated.
"""
msg_table = {
- "parse_error" : "could not parse /etc/bootconf.conf",
- "parse_error2" : "could not parse /var/bootconf/bootconf.conf",
+ "parse_error" : "could not parse /etc/cobber.conf",
+ "parse_error2" : "could not parse /var/cobbler/cobbler.conf",
"no_create" : "cannot create: %s",
"no_args" : "this command requires arguments.",
"missing_options" : "cannot add, all parameters have not been set",
- "unknown_cmd" : "bootconf doesn't understand '%s'",
+ "unknown_cmd" : "cobber doesn't understand '%s'",
"bad_arg" : "expecting an equal sign in argument '%s'",
"reject_arg" : "the value of parameter '%s' is not valid",
"weird_arg" : "this command doesn't take a parameter named '%s'",
"bad_sys_name" : "system name must be a MAC, IP, or resolveable host",
- "usage" : "for help, run 'bootconf help'",
+ "usage" : "for help, see 'man cobbler'",
"need_to_fix" : "the following potential problems were detected:",
- "need_root" : "bootconf must be run as root",
+ "need_root" : "cobber must be run as root",
"no_dhcpd" : "can't find dhcpd, try 'yum install dhcpd'",
"no_pxelinux" : "can't find pxelinux, try 'yum install pxelinux'",
"no_tftpd" : "can't find tftpd, try 'yum install tftpd'",
@@ -27,8 +27,8 @@ msg_table = {
"chg_attrib" : "need to change '%s' to '%s' in '%s'",
"no_exist" : "%s does not exist",
"no_line" : "file '%s' should have a line '%s' somewhere",
- "no_dir2" : "can't find %s for %s in bootconf.conf",
- "no_cfg" : "could not find bootconf.conf, recreating",
+ "no_dir2" : "can't find %s for %s in cobber.conf",
+ "no_cfg" : "could not find cobber.conf, recreating",
"bad_param" : "at least one parameter is missing for this function",
"empty_list" : "(Empty)",
"err_resolv" : "system (%s) did not resolve",
@@ -46,11 +46,11 @@ msg_table = {
"check_ok" : """
No setup problems found.
-Manual editing of /etc/dhcpd.conf and /etc/bootconf.conf is suggested to tailor them to your specific configuration. Your dhcpd.conf has some PXE related information in it, but it's imposible to tell automatically that it's totally correct in a general sense. We'll leave this up to you.
+Manual editing of /etc/dhcpd.conf and /etc/cobber.conf is suggested to tailor them to your specific configuration. Your dhcpd.conf has some PXE related information in it, but it's imposible to tell automatically that it's totally correct in a general sense. We'll leave this up to you.
Good luck.
""",
- "help" : "see 'man bootconf'"
+ "help" : "see 'man cobber'"
}
def m(key):
@@ -1,4 +1,4 @@
-# Messages used by bootconf.
+# Messages used by cobber.
# Michael DeHaan <mdehaan@redhat.com>
"""